# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Resource types

* [`opnsense_device`](#opnsense_device): Manage an OPNsense device access.
* [`opnsense_plugin`](#opnsense_plugin): Manage installed opnsense plugins

## Resource types

### <a name="opnsense_device"></a>`opnsense_device`

This type provides Puppet with the capabilities to manage OPNSense device access data.

* **See also**
  * https://docs.opnsense.org/development/how-tos/api.html#use-the-api

#### Examples

##### 

```puppet
opnsense_device { 'opnsense.example.com':
  url        => 'https://opnsense.example.com/api',
  api_key    => 'your_api_key',
  api_secret => Sensitive('your_api_secret'),
  timeout    => 60,
  ssl_verify => true,
  ca         => '/path/to/ca.pem',
  ensure     => 'present',
}
```

#### Properties

The following properties are available in the `opnsense_device` type.

##### `api_key`

Data type: `String`

The api key from the generated key/secret pair.

##### `api_secret`

Data type: `Sensitive[String]`

The api secret from the generated key/secret pair.

##### `ca`

Data type: `Optional[String]`

The path to the ca bundle file for ssl verification.

##### `ensure`

Data type: `Enum[present, absent]`

Whether this resource should be present or absent on the target system.

Default value: `present`

##### `ssl_verify`

Data type: `Boolean`

The timeout for API calls in seconds.

Default value: `true`

##### `timeout`

Data type: `Integer`

The timeout for API calls in seconds.

Default value: `60`

##### `url`

Data type: `String`

The api url of the OPNsense device.

#### Parameters

The following parameters are available in the `opnsense_device` type.

* [`name`](#name)

##### <a name="name"></a>`name`

namevar

Data type: `Pattern[/\A[0-9A-Za-z.-]+/]`
_*this data type contains a regex that may not be accurately reflected in generated documentation_

The name of the OPNsense device you want to manage.

### <a name="opnsense_plugin"></a>`opnsense_plugin`

This type provides Puppet with the capabilities to manage opnsense plugins.

* **See also**
  * https://docs.opnsense.org/plugins.html

#### Examples

##### 

```puppet
opnsense_plugin { 'os-acme-client':
  device => 'opnsense.example.com'
  ensure => 'present',
}
```

#### Properties

The following properties are available in the `opnsense_plugin` type.

##### `ensure`

Data type: `Enum[present, absent]`

Whether this plugin should be present or absent on the opnsense device.

Default value: `present`

#### Parameters

The following parameters are available in the `opnsense_plugin` type.

* [`device`](#device)
* [`name`](#name)

##### <a name="device"></a>`device`

namevar

Data type: `String`

The name of the opnsense_device type you want to manage.

##### <a name="name"></a>`name`

namevar

Data type: `String`

The name of the plugin you want to manage.

